@@ -1,4 +1,3 @@
-
 import munge
 
 
@@ -6,14 +5,16 @@ class Config(munge.Config):
     """
     command line interface config
     """
+
     defaults = {
-        'config': {
-            'rdap': {
-                "bootstrap_url": "https://rdap.db.ripe.net/",
+        "config": {
+            "rdap": {
+                "bootstrap_url": "https://rdap.org/",
                 "output_format": "yaml",
                 "recurse_roles": ["administrative", "technical"],
                 "lacnic_apikey": None,
-                },
+                "timeout": 0.5,
             },
-        'codec': 'yaml',
-        }
+        },
+        "codec": "yaml",
+    }
